@@ -195,9 +195,9 @@ class waveformFile:
 		#at this point we want to read all of the headers in from the files
 		#and save it as a pandas dataframe
 		#but only if it actually has data in it
-		if self.__files is not None:
-			if bulkRead: #in this case the headers are already prepped in the temp header array
-				self.__headers = pd.DataFrame(self.__tempHeaders)
+		if self.__files is not None: #if there is data that was read in
+			if isinstance(self.__files['header'], np.ndarray): #if this is a numpy array, then do this with it
+				self.__headers = pd.DataFrame(self.__files['header'])
 				del self.__tempHeaders
 			elif isinstance(self.__files['header'], da.core.Array): #if they haven't been loaded in, do so now
 				self.__headers = pd.DataFrame(self.__files['header'].compute()) #load the headers into memory
